==> pimcommon-17.07.90.tar.xz: pimcommon-17.07.90/src/pimcommonakonadi/util/mailutil.cpp <==
/*******************************************************************************
**
** Filename   : util
** Created on : 03 April, 2005
** Copyright  : (c) 2005 Till Adam
** Email      : <adam@kde.org>
**
*******************************************************************************/

/*******************************************************************************
**
**   This program is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
**   It is distributed in the hope that it will be useful, but
**   WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**   General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with this program; if not, write to the Free Software
**   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**   In addition, as a special exception, the copyright holders give
**   permission to link the code of this program with any edition of
**   the Qt library by Trolltech AS, Norway (or with modified versions
**   of Qt that use the same license as Qt), and distribute linked
**   combinations including the two.  You must obey the GNU General
**   Public License in all respects for all of the code used other than
**   Qt.  If you modify this file, you may extend this exception to
**   your version of the file, but you are not obligated to do so.  If
**   you do not wish to do so, delete this exception statement from
**   your version.
**
*******************************************************************************/

#include "mailutil.h"
#include <PimCommon/PimUtil>

#include <AgentInstance>
#include <AkonadiCore/AgentManager>
#include <AkonadiCore/ServerManager>

bool PimCommon::MailUtil::isImapFolder(const Akonadi::Collection &col, bool &isOnline)
{
    const Akonadi::AgentInstance agentInstance = Akonadi::AgentManager::self()->instance(col.resource());
    isOnline = agentInstance.isOnline();

    return PimCommon::Util::isImapResource(agentInstance.type().identifier());
}

QString PimCommon::MailUtil::indexerServiceName()
{
    QLatin1String basename("org.freedesktop.Akonadi.Agent.akonadi_indexing_agent");
    if (Akonadi::ServerManager::hasInstanceIdentifier()) {
        return basename + QLatin1Char('.') + Akonadi::ServerManager::instanceIdentifier();
    } else {
        return basename;
    }
}

==> pimcommon-18.04.0.tar.xz: pimcommon-18.04.0/src/pimcommonakonadi/util/mailutil.cpp <==
/*******************************************************************************
**
** Filename   : util
** Created on : 03 April, 2005
** Copyright  : (c) 2005 Till Adam
** Email      : <adam@kde.org>
**
*******************************************************************************/

/*******************************************************************************
**
**   This program is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
**   It is distributed in the hope that it will be useful, but
**   WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**   General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with this program; if not, write to the Free Software
**   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**   In addition, as a special exception, the copyright holders give
**   permission to link the code of this program with any edition of
**   the Qt library by Trolltech AS, Norway (or with modified versions
**   of Qt that use the same license as Qt), and distribute linked
**   combinations including the two.  You must obey the GNU General
**   Public License in all respects for all of the code used other than
**   Qt.  If you modify this file, you may extend this exception to
**   your version of the file, but you are not obligated to do so.  If
**   you do not wish to do so, delete this exception statement from
**   your version.
**
*******************************************************************************/

#include "mailutil.h"
#include <PimCommon/PimUtil>

#include <AgentInstance>
#include <AkonadiCore/AgentManager>
#include <AkonadiCore/ServerManager>

bool PimCommon::MailUtil::isImapFolder(const Akonadi::Collection &col, bool &isOnline)
{
    const Akonadi::AgentInstance agentInstance = Akonadi::AgentManager::self()->instance(col.resource());
    isOnline = agentInstance.isOnline();

    return PimCommon::Util::isImapResource(agentInstance.type().identifier());
}

QString PimCommon::MailUtil::indexerServiceName()
{
    return Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent,
                                                    QStringLiteral("akonadi_indexing_agent"));
}
